@@ -25,6 +25,7 @@
 #include "gnunet_chat_lib.h"
 
 #include <limits.h>
+#include <strings.h>
 
 #include "gnunet_chat_contact.h"
 #include "gnunet_chat_context.h"
@@ -72,7 +73,7 @@ GNUNET_CHAT_stop (struct GNUNET_CHAT_Handle *handle)
 
   handle->destruction = GNUNET_SCHEDULER_add_at_with_priority(
       GNUNET_TIME_absolute_get(),
-      GNUNET_SCHEDULER_PRIORITY_IDLE,
+      GNUNET_SCHEDULER_PRIORITY_URGENT,
       task_handle_destruction,
       handle
   );
@@ -255,7 +256,7 @@ GNUNET_CHAT_uri_parse (const char *uri,
 
   const size_t prefix_len = strlen(GNUNET_CHAT_URI_PREFIX);
 
-  if (0 != strncmp(GNUNET_CHAT_URI_PREFIX, uri, prefix_len))
+  if (0 != strncasecmp(GNUNET_CHAT_URI_PREFIX, uri, prefix_len))
   {
     if (emsg)
       *emsg = GNUNET_strdup (_ ("CHAT URI malformed (invalid prefix)"));
@@ -1326,29 +1327,7 @@ GNUNET_CHAT_message_get_kind (const struct GNUNET_CHAT_Message *message)
   if (!(message->msg))
     return GNUNET_CHAT_KIND_UNKNOWN;
 
-  switch (message->msg->header.kind)
-  {
-    case GNUNET_MESSENGER_KIND_JOIN:
-      return GNUNET_CHAT_KIND_JOIN;
-    case GNUNET_MESSENGER_KIND_LEAVE:
-      return GNUNET_CHAT_KIND_LEAVE;
-    case GNUNET_MESSENGER_KIND_NAME:
-    case GNUNET_MESSENGER_KIND_KEY:
-    case GNUNET_MESSENGER_KIND_ID:
-      return GNUNET_CHAT_KIND_CONTACT;
-    case GNUNET_MESSENGER_KIND_INVITE:
-      return GNUNET_CHAT_KIND_INVITATION;
-    case GNUNET_MESSENGER_KIND_TEXT:
-      return GNUNET_CHAT_KIND_TEXT;
-    case GNUNET_MESSENGER_KIND_FILE:
-      return GNUNET_CHAT_KIND_FILE;
-    case GNUNET_MESSENGER_KIND_PRIVATE:
-      return GNUNET_CHAT_KIND_WHISPER;
-    case GNUNET_MESSENGER_KIND_DELETE:
-      return GNUNET_CHAT_KIND_DELETION;
-    default:
-      return GNUNET_CHAT_KIND_UNKNOWN;
-  }
+  return util_message_kind_from_kind(message->msg->header.kind);
 }
 
 
